R/CreateMultiHetObjects.R
create.multiplex.Rdcreate.multiplex is a function to create a multiplex network
(Multiplex object) from a list of individual networks defined as
igraph objects. See more details about multiplex networks below.
If just one network is provided, a Multiplex object with one layer is
therefore created (A monoplex network).
create.multiplex(...)
# Default S3 method
create.multiplex(LayersList, ...)A Multiplex object. It contains a list of the different graphs integrating the multiplex network, the names and number of its nodes and the number of layers.
A multiplex network is a collection of layers (monoplex networks) sharing the same nodes, but in which the edges represent relationships of different nature. At least a list with one element, an igraph object, should be provided.
m1 <- igraph::make_graph(c(1,2,1,3,2,3), directed = FALSE)
m2 <- igraph::make_graph(c(1,3,2,3,3,4,1,4), directed = FALSE)
multiObject <- create.multiplex(list(m1=m1,m2=m2))