A Multiplex Heterogeneous object is an R object generated as the result of calling the function create.multiplexHet

isMultiplexHet(x)

Arguments

x

An R object

Value

A logical constant, TRUE if argument x is a MultiplexHet object.

Details

isMultiplexHet(x) checks whether an R object is MultiplexHet

Author

Alberto Valdeolivas Urbelz alvaldeolivas@gmail.com

Examples

m1 <- igraph::make_graph(c(1,2,1,3,2,3), directed = FALSE)
m2 <- igraph::make_graph(c(1,3,2,3,3,4,1,4), directed = FALSE)
multiObject_1 <- create.multiplex(list(m1=m1,m2=m2))
h1 <- igraph::make_graph(c("A","C","B","E","E","D","E","C"), directed = FALSE)
multiObject_2 <- create.multiplex(list(h1=h1))
bipartite_relations <- data.frame(m=c(1,3),h=c("A","E"))
multiHetObject <- 
    create.multiplexHet(multiObject_1,multiObject_2,bipartite_relations)
#> checking input arguments...
#> Generating bipartite matrix...
#> Expanding bipartite matrix to fit the multiplex network...
isMultiplexHet(multiHetObject)
#> [1] TRUE
isMultiplexHet(h1)
#> [1] FALSE