A RWR on Multiplex object is an R object generated as the result of calling the function Random.Walk.Restart.Multiplex (Results of the RWR-M)

isRWRM_Results(x)

Arguments

x

An R object

Value

A logical constant, TRUE if argument x is a RWRM_Results object.

Details

isRWRM_Results(x) checks whether an R object is RWRM_Results

Author

Alberto Valdeolivas Urbelz alvaldeolivas@gmail.com

Examples

m1 <- igraph::make_graph(c(1,2,1,3,2,3), directed = FALSE)
m2 <- igraph::make_graph(c(1,3,2,3,3,4,1,4), directed = FALSE)
multiObject <- create.multiplex(list(m1=m1,m2=m2))
AdjMatrix <- compute.adjacency.matrix(multiObject)
AdjMatrixNorm <- normalize.multiplex.adjacency(AdjMatrix)
Seed <- c(1)
RWR_MultiResults <- 
    Random.Walk.Restart.Multiplex(AdjMatrixNorm, multiObject,Seed)
isRWRM_Results(RWR_MultiResults)
#> [1] TRUE
isRWRM_Results(m1)
#> [1] FALSE