R/InduceNetworks.R
create.multiplexNetwork.topResults.Rdcreate.multiplexNetwork.topResults is a function to create a network
from the top results of the Random Walk with Restart on Multiplex networks
algorithm (a RWRM_Results object).
create.multiplexNetwork.topResults(RWRM_Result_Object,
MultiplexObject,k=25)A RWRM_Results object generated by the
function Random.Walk.Restart.Multiplex representing the results
of the Random Ralk with restart on the multiplex network described in the
following argument.
A Multiplex object generated by the
function create.multiplex representing a multiplex network.
A numeric value between 1 and 200. It is the number of top ranked nodes to be included in the resulting multiplex network.
An igraph object containing the top k ranked
multiplex nodes in the Random Walk with Restart on a Multiplex network
algorithm. We include all the possible types of interactions between pairs of
nodes according to the different layers of the multiplex network.
m1 <- igraph::make_graph(c(1,2,1,3,2,3), directed = FALSE)
m2 <- igraph::make_graph(c(1,3,2,3,3,4,1,4), directed = FALSE)
multiObject <- create.multiplex(list(m1=m1,m2=m2))
AdjMatrix <- compute.adjacency.matrix(multiObject)
AdjMatrixNorm <- normalize.multiplex.adjacency(AdjMatrix)
Seed <- c(1)
RWR_MultiResults <-
Random.Walk.Restart.Multiplex(AdjMatrixNorm, multiObject, Seed)
create.multiplexNetwork.topResults(RWR_MultiResults,multiObject)
#> IGRAPH 685889a UNW- 4 7 --
#> + attr: name (v/c), comp (v/n), weight (e/n), type (e/c)
#> + edges from 685889a (vertex names):
#> [1] 1--2 1--3 2--3 1--3 1--4 2--3 3--4